opus_encoder_get_size

Function opus_encoder_get_size 

pub unsafe extern "C" fn opus_encoder_get_size(
    channels: c_int,
) -> c_int
Gets the size of an OpusEncoder structure. @param[in] channels int: Number of channels. This must be 1 or 2. @returns The size in bytes. @note Since this function does not take the application as input, it will overestimate the size required for OPUS_APPLICATION_RESTRICTED_SILK and OPUS_APPLICATION_RESTRICTED_CELT. That is generally not a problem, except when trying to know the size to use for a copy.